Trait bitflags::__core::prelude::v1::PartialEq 1.0.0
[−]
[src]
pub trait PartialEq<Rhs = Self> where Rhs: ?Sized {
fn eq(&self, other: &Rhs) -> bool;
fn ne(&self, other: &Rhs) -> bool { ... }
}Trait for equality comparisons which are partial equivalence relations.
This trait allows for partial equality, for types that do not have a full
equivalence relation. For example, in floating point numbers NaN != NaN,
so floating point types implement PartialEq but not Eq.
Formally, the equality must be (for all a, b and c):
- symmetric:
a == bimpliesb == a; and - transitive:
a == bandb == cimpliesa == c.
Note that these requirements mean that the trait itself must be implemented
symmetrically and transitively: if T: PartialEq<U> and U: PartialEq<V>
then U: PartialEq<T> and T: PartialEq<V>.
Derivable
This trait can be used with #[derive]. When derived on structs, two
instances are equal if all fields are equal, and not equal if any fields
are not equal. When derived on enums, each variant is equal to itself
and not equal to the other variants.
How can I implement PartialEq?
PartialEq only requires the eq method to be implemented; ne is defined
in terms of it by default. Any manual implementation of ne must respect
the rule that eq is a strict inverse of ne; that is, !(a == b) if and
only if a != b.
An example implementation for a domain in which two books are considered the same book if their ISBN matches, even if the formats differ:
enum BookFormat { Paperback, Hardback, Ebook } struct Book { isbn: i32, format: BookFormat, } impl PartialEq for Book { fn eq(&self, other: &Book) -> bool { self.isbn == other.isbn } } let b1 = Book { isbn: 3, format: BookFormat::Paperback }; let b2 = Book { isbn: 3, format: BookFormat::Ebook }; let b3 = Book { isbn: 10, format: BookFormat::Paperback }; assert!(b1 == b2); assert!(b1 != b3);
Examples
let x: u32 = 0; let y: u32 = 1; assert_eq!(x == y, false); assert_eq!(x.eq(&y), false);
Required Methods
fn eq(&self, other: &Rhs) -> bool
This method tests for self and other values to be equal, and is used
by ==.
Provided Methods
fn ne(&self, other: &Rhs) -> bool
This method tests for !=.
Implementors
impl<T> PartialEq<Wrapping<T>> for Wrapping<T> where T: PartialEq<T>impl PartialEq<ParseFloatError> for ParseFloatErrorimpl PartialEq<FpCategory> for FpCategoryimpl PartialEq<ParseIntError> for ParseIntErrorimpl<T> PartialEq<NonZero<T>> for NonZero<T> where T: Zeroable + PartialEq<T>impl<T> PartialEq<*const T> for *const T where T: ?Sizedimpl<T> PartialEq<*mut T> for *mut T where T: ?Sizedimpl<Ret> PartialEq<fn() -> Ret> for fn() -> Retimpl<Ret> PartialEq<extern fn() -> Ret> for extern fn() -> Retimpl<Ret> PartialEq<unsafe fn() -> Ret> for unsafe fn() -> Retimpl<Ret> PartialEq<unsafe extern fn() -> Ret> for unsafe extern fn() -> Retimpl<Ret, A> PartialEq<fn(A) -> Ret> for fn(A) -> Retimpl<Ret, A> PartialEq<extern fn(A) -> Ret> for extern fn(A) -> Retimpl<Ret, A> PartialEq<unsafe fn(A) -> Ret> for unsafe fn(A) -> Retimpl<Ret, A> PartialEq<unsafe extern fn(A) -> Ret> for unsafe extern fn(A) -> Retimpl<Ret, A, B> PartialEq<fn(A, B) -> Ret> for fn(A, B) -> Retimpl<Ret, A, B> PartialEq<extern fn(A, B) -> Ret> for extern fn(A, B) -> Retimpl<Ret, A, B> PartialEq<unsafe fn(A, B) -> Ret> for unsafe fn(A, B) -> Retimpl<Ret, A, B> PartialEq<unsafe extern fn(A, B) -> Ret> for unsafe extern fn(A, B) -> Retimpl<Ret, A, B, C> PartialEq<fn(A, B, C) -> Ret> for fn(A, B, C) -> Retimpl<Ret, A, B, C> PartialEq<extern fn(A, B, C) -> Ret> for extern fn(A, B, C) -> Retimpl<Ret, A, B, C> PartialEq<unsafe fn(A, B, C) -> Ret> for unsafe fn(A, B, C) -> Retimpl<Ret, A, B, C> PartialEq<unsafe extern fn(A, B, C) -> Ret> for unsafe extern fn(A, B, C) -> Retimpl<Ret, A, B, C, D> PartialEq<fn(A, B, C, D) -> Ret> for fn(A, B, C, D) -> Retimpl<Ret, A, B, C, D> PartialEq<extern fn(A, B, C, D) -> Ret> for extern fn(A, B, C, D) -> Retimpl<Ret, A, B, C, D> PartialEq<unsafe fn(A, B, C, D) -> Ret> for unsafe fn(A, B, C, D) -> Retimpl<Ret, A, B, C, D> PartialEq<unsafe extern fn(A, B, C, D) -> Ret> for unsafe extern fn(A, B, C, D) -> Retimpl<Ret, A, B, C, D, E> PartialEq<fn(A, B, C, D, E) -> Ret> for fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E> PartialEq<extern fn(A, B, C, D, E) -> Ret> for extern fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E> PartialEq<unsafe fn(A, B, C, D, E) -> Ret> for unsafe fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E> PartialEq<unsafe extern fn(A, B, C, D, E) -> Ret> for unsafe extern fn(A, B, C, D, E) -> Retimpl<Ret, A, B, C, D, E, F> PartialEq<fn(A, B, C, D, E, F) -> Ret> for fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F> PartialEq<extern fn(A, B, C, D, E, F) -> Ret> for extern fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F> PartialEq<unsafe fn(A, B, C, D, E, F) -> Ret> for unsafe fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F> PartialEq<unsafe extern fn(A, B, C, D, E, F) -> Ret> for unsafe extern fn(A, B, C, D, E, F) -> Retimpl<Ret, A, B, C, D, E, F, G> PartialEq<fn(A, B, C, D, E, F, G) -> Ret> for fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G> PartialEq<extern fn(A, B, C, D, E, F, G) -> Ret> for extern fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G> PartialEq<unsafe fn(A, B, C, D, E, F, G) -> Ret> for unsafe fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G> PartialEq<unsafe extern fn(A, B, C, D, E, F, G) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<fn(A, B, C, D, E, F, G, H) -> Ret> for fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<extern fn(A, B, C, D, E, F, G, H) -> Ret> for extern fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<unsafe fn(A, B, C, D, E, F, G, H) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H> PartialEq<unsafe extern fn(A, B, C, D, E, F, G, H) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G, H) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<fn(A, B, C, D, E, F, G, H, I) -> Ret> for fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<extern fn(A, B, C, D, E, F, G, H, I) -> Ret> for extern fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I> PartialEq<unsafe extern fn(A, B, C, D, E, F, G, H, I) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G, H, I) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<extern fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for extern fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J> PartialEq<unsafe extern fn(A, B, C, D, E, F, G, H, I, J) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G, H, I, J) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<extern fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for extern fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K> PartialEq<unsafe extern fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G, H, I, J, K) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<extern fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for extern fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<unsafe extern fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret> for unsafe extern fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Retimpl<T> PartialEq<PhantomData<T>> for PhantomData<T> where T: ?Sizedimpl PartialEq<RangeFull> for RangeFullimpl<Idx> PartialEq<Range<Idx>> for Range<Idx> where Idx: PartialEq<Idx>impl<Idx> PartialEq<RangeFrom<Idx>> for RangeFrom<Idx> where Idx: PartialEq<Idx>impl<Idx> PartialEq<RangeTo<Idx>> for RangeTo<Idx> where Idx: PartialEq<Idx>impl<Idx> PartialEq<RangeInclusive<Idx>> for RangeInclusive<Idx> where Idx: PartialEq<Idx>impl<Idx> PartialEq<RangeToInclusive<Idx>> for RangeToInclusive<Idx> where Idx: PartialEq<Idx>impl PartialEq<Ordering> for Orderingimpl PartialEq<()> for ()impl PartialEq<bool> for boolimpl PartialEq<char> for charimpl PartialEq<usize> for usizeimpl PartialEq<u8> for u8impl PartialEq<u16> for u16impl PartialEq<u32> for u32impl PartialEq<u64> for u64impl PartialEq<isize> for isizeimpl PartialEq<i8> for i8impl PartialEq<i16> for i16impl PartialEq<i32> for i32impl PartialEq<i64> for i64impl PartialEq<f32> for f32impl PartialEq<f64> for f64impl<'a, 'b, A, B> PartialEq<&'b B> for &'a A where A: PartialEq<B> + ?Sized, B: ?Sizedimpl<'a, 'b, A, B> PartialEq<&'b mut B> for &'a mut A where A: PartialEq<B> + ?Sized, B: ?Sizedimpl<'a, 'b, A, B> PartialEq<&'b mut B> for &'a A where A: PartialEq<B> + ?Sized, B: ?Sizedimpl<'a, 'b, A, B> PartialEq<&'b B> for &'a mut A where A: PartialEq<B> + ?Sized, B: ?Sizedimpl PartialEq<TypeId> for TypeIdimpl<'a, 'b, A, B> PartialEq<[B; 0]> for [A; 0] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 0] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 0]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 0] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 0]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 0] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 0]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 1]> for [A; 1] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 1] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 1]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 1] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 1]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 1] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 1]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 2]> for [A; 2] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 2] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 2]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 2] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 2]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 2] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 2]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 3]> for [A; 3] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 3] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 3]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 3] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 3]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 3] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 3]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 4]> for [A; 4] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 4] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 4]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 4] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 4]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 4] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 4]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 5]> for [A; 5] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 5] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 5]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 5] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 5]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 5] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 5]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 6]> for [A; 6] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 6] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 6]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 6] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 6]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 6] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 6]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 7]> for [A; 7] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 7] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 7]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 7] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 7]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 7] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 7]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 8]> for [A; 8] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 8] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 8]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 8] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 8]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 8] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 8]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 9]> for [A; 9] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 9] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 9]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 9] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 9]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 9] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 9]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 10]> for [A; 10] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 10] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 10]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 10] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 10]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 10] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 10]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 11]> for [A; 11] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 11] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 11]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 11] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 11]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 11] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 11]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 12]> for [A; 12] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 12] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 12]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 12] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 12]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 12] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 12]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 13]> for [A; 13] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 13] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 13]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 13] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 13]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 13] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 13]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 14]> for [A; 14] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 14] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 14]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 14] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 14]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 14] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 14]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 15]> for [A; 15] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 15] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 15]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 15] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 15]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 15] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 15]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 16]> for [A; 16] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 16] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 16]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 16] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 16]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 16] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 16]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 17]> for [A; 17] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 17] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 17]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 17] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 17]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 17] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 17]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 18]> for [A; 18] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 18] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 18]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 18] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 18]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 18] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 18]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 19]> for [A; 19] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 19] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 19]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 19] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 19]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 19] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 19]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 20]> for [A; 20] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 20] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 20]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 20] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 20]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 20] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 20]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 21]> for [A; 21] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 21] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 21]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 21] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 21]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 21] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 21]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 22]> for [A; 22] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 22] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 22]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 22] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 22]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 22] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 22]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 23]> for [A; 23] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 23] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 23]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 23] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 23]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 23] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 23]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 24]> for [A; 24] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 24] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 24]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 24] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 24]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 24] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 24]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 25]> for [A; 25] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 25] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 25]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 25] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 25]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 25] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 25]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 26]> for [A; 26] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 26] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 26]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 26] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 26]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 26] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 26]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 27]> for [A; 27] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 27] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 27]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 27] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 27]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 27] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 27]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 28]> for [A; 28] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 28] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 28]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 28] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 28]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 28] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 28]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 29]> for [A; 29] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 29] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 29]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 29] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 29]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 29] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 29]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 30]> for [A; 30] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 30] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 30]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 30] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 30]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 30] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 30]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 31]> for [A; 31] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 31] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 31]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 31] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 31]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 31] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 31]> for &'b mut [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<[B; 32]> for [A; 32] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[B]> for [A; 32] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 32]> for [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b [B]> for [A; 32] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 32]> for &'b [B] where B: PartialEq<A>impl<'a, 'b, A, B> PartialEq<&'b mut [B]> for [A; 32] where A: PartialEq<B>impl<'a, 'b, A, B> PartialEq<[A; 32]> for &'b mut [B] where B: PartialEq<A>impl<T> PartialEq<Cell<T>> for Cell<T> where T: Copy + PartialEq<T>impl PartialEq<BorrowState> for BorrowStateimpl<T> PartialEq<RefCell<T>> for RefCell<T> where T: PartialEq<T> + ?Sizedimpl<T> PartialEq<Option<T>> for Option<T> where T: PartialEq<T>impl<T, E> PartialEq<Result<T, E>> for Result<T, E> where E: PartialEq<E>, T: PartialEq<T>impl<A, B> PartialEq<[B]> for [A] where A: PartialEq<B>impl PartialEq<SearchStep> for SearchStepimpl PartialEq<ParseBoolError> for ParseBoolErrorimpl PartialEq<Utf8Error> for Utf8Errorimpl PartialEq<str> for strimpl PartialEq<Error> for Errorimpl<A> PartialEq<(A,)> for (A,) where A: PartialEq<A>impl<A, B> PartialEq<(A, B)> for (A, B) where A: PartialEq<A>, B: PartialEq<B>impl<A, B, C> PartialEq<(A, B, C)> for (A, B, C) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>impl<A, B, C, D> PartialEq<(A, B, C, D)> for (A, B, C, D) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>impl<A, B, C, D, E> PartialEq<(A, B, C, D, E)> for (A, B, C, D, E) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>impl<A, B, C, D, E, F> PartialEq<(A, B, C, D, E, F)> for (A, B, C, D, E, F) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>impl<A, B, C, D, E, F, G> PartialEq<(A, B, C, D, E, F, G)> for (A, B, C, D, E, F, G) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>impl<A, B, C, D, E, F, G, H> PartialEq<(A, B, C, D, E, F, G, H)> for (A, B, C, D, E, F, G, H) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>, H: PartialEq<H>impl<A, B, C, D, E, F, G, H, I> PartialEq<(A, B, C, D, E, F, G, H, I)> for (A, B, C, D, E, F, G, H, I) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>, H: PartialEq<H>, I: PartialEq<I>impl<A, B, C, D, E, F, G, H, I, J> PartialEq<(A, B, C, D, E, F, G, H, I, J)> for (A, B, C, D, E, F, G, H, I, J) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>, H: PartialEq<H>, I: PartialEq<I>, J: PartialEq<J>impl<A, B, C, D, E, F, G, H, I, J, K> PartialEq<(A, B, C, D, E, F, G, H, I, J, K)> for (A, B, C, D, E, F, G, H, I, J, K) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>, H: PartialEq<H>, I: PartialEq<I>, J: PartialEq<J>, K: PartialEq<K>impl<A, B, C, D, E, F, G, H, I, J, K, L> PartialEq<(A, B, C, D, E, F, G, H, I, J, K, L)> for (A, B, C, D, E, F, G, H, I, J, K, L) where A: PartialEq<A>, B: PartialEq<B>, C: PartialEq<C>, D: PartialEq<D>, E: PartialEq<E>, F: PartialEq<F>, G: PartialEq<G>, H: PartialEq<H>, I: PartialEq<I>, J: PartialEq<J>, K: PartialEq<K>, L: PartialEq<L>